/*
  Copyright (C) 2012
  Alejandro Mujica (amujica@cenditel.gob.ve)
  Erwin Paredes (eparedes@cenditel.gob.ve)
  José Ruiz (jruiz@cenditel.gob.ve)
  Rodolfo Rangel (rrangel@cenditel.gob.ve)
  Julie Vera (jvera@cenditel.gob.ve)

  CENDITEL Fundación Centro Nacional de Desarrollo e Investigación en
  Tecnologías Libres

  Este programa es software libre; Usted puede usarlo bajo los términos de la
  licencia de software GPL versión 2.0 de la Free Software Foundation.

  Este programa se distribuye con la esperanza de que sea útil, pero SIN
  NINGUNA GARANTÍA; tampoco las implícitas garantías de MERCANTILIDAD o
  ADECUACIÓN A UN PROPÓSITO PARTICULAR.
  Consulte la licencia GPL para más detalles. Usted debe recibir una copia
  de la GPL junto con este programa; si no, escriba a la Free Software
  Foundation Inc. 51 Franklin Street,5 Piso, Boston, MA 02110-1301, USA.
*/

/*
  Este archivo contiene la especificación de la clase TempFilterForm, la cual
  repesenta el formulario utilizado para filtrar los productos que serán las
  raíces de la red que se va a construir para estudiar.

  Autor: Alejandro J. Mujica
  Fecha: 04/12/2013
*/

# ifndef TEMP_FILTER_FORM_H
# define TEMP_FILTER_FORM_H

# include <QWidget>
# include <QProcess>

# include <ui_tempFilter.h>

# include <waitingPanel.H>

# include <queries.H>

class TempFilterForm : public QWidget {
    Q_OBJECT

    AutoConnection conn;

    Ui_TempFilter ui;

    QListWidgetItem * selectedItem;

    Tree<long> productIdSet;

    Map<std::string, unsigned short> yearsMap;

    WaitingPanel waitingPanel;

    QProcess process;

    void moveToCenter(QWidget *);

    void updateComboYear();

protected:
    void closeEvent(QCloseEvent *);

public:
    explicit TempFilterForm(QWidget * parent = 0);
    
signals:
    void signalFormAccepted();

    void signalClosing();
    
private slots:
    void slotBtnAcceptClicked();

    void slotTextChanged();

    void slotCompanySelected(QListWidgetItem *);

    void slotProductSelected(QListWidgetItem *);

    void slotSelectedProductSelected(QListWidgetItem *);

    void slotBtnAddProductToSelectedListClicked();

    void slotBtnRemoveProductFromSelectedList();

    void slotGraphBuilderExecuted();
    
};

# endif // TEMP_FILTER_FORM_H
